#  tests for cartopy-0.21.1-py311hd30dfa7_0 (this is a generated file);
print('===== testing package: cartopy-0.21.1-py311hd30dfa7_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import cartopy
import cartopy.mpl.geoaxes
import cartopy.crs as ccrs

import matplotlib
matplotlib.use('agg')
import matplotlib.pyplot as plt

ax = plt.axes(projection=ccrs.Robinson())
ax.coastlines()
plt.savefig('working.png')
#  --- run_test.py (end) ---

print('===== cartopy-0.21.1-py311hd30dfa7_0 OK =====');
